pub(super) fn patch_json_for_outdated_configs(json: &mut Value)Expand description
This function patches the json config to the new expected keys. That is we try to load old known config keys here and convert them to the new ones. See https://github.com/rust-lang/rust-analyzer/pull/12010
We already have an alias system for simple cases, but if we make structural changes the alias infra fails down.